@@ -217,6 +217,14 @@ DEFAULT_CLI_ARGS = {
                      "(status and stdout still included for other events)"
             ),
         ),
+        (
+            ("--omit-env-files",),
+            dict(
+                action="store_true",
+                dest='suppress_env_files',
+                help="Add flag to prevent the writing of the env directory"
+            ),
+        ),
         (
             ("-q", "--quiet",),
             dict(
@@ -895,7 +903,8 @@ def main(sys_args=None):
                                    resource_profiling_results_dir=vargs.get('resource_profiling_results_dir'),
                                    cmdline=vargs.get('cmdline'),
                                    limit=vargs.get('limit'),
-                                   streamer=streamer
+                                   streamer=streamer,
+                                   suppress_env_files=vargs.get("suppress_env_files"),
                                    )
                 try:
                     res = run(**run_options)
