@@ -204,8 +204,12 @@ class Runner(object):
             user = getpass.getuser()
             group = grp.getgrgid(os.getgid()).gr_name
 
-            cmd = 'cgcreate -a {user}:{group} -t {user}:{group} -g cpuacct,memory,pids:{}'.format(cgroup_path, user=user, group=group)
-            proc = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
+            cmd = ['cgcreate',
+                   '-a', f'{user}:{group}',
+                   '-t', f'{user}:{group}',
+                   '-g', f'cpuacct,memory,pids:{cgroup_path}',
+                   ]
+            proc = Popen(cmd, stdout=PIPE, stderr=PIPE)
             _, stderr = proc.communicate()
             if proc.returncode:
                 # Unable to create cgroup
@@ -249,12 +253,11 @@ class Runner(object):
                     'stderr': error_fd,
                     'check': True,
                     'universal_newlines': True,
-                    'shell': True
                 }
                 if subprocess_timeout is not None:
                     kwargs.update({'timeout': subprocess_timeout})
 
-                proc_out = run_subprocess(" ".join(command), **kwargs)
+                proc_out = run_subprocess(command, **kwargs)
 
                 stdout_response = proc_out.stdout
                 stderr_response = proc_out.stderr
@@ -391,8 +394,8 @@ class Runner(object):
                 return True
             _delete()
         if self.resource_profiling:
-            cmd = 'cgdelete -g cpuacct,memory,pids:{}'.format(cgroup_path)
-            proc = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
+            cmd = ['cgdelete', '-g', f'cpuacct,memory,pids:{cgroup_path}']
+            proc = Popen(cmd, stdout=PIPE, stderr=PIPE)
             _, stderr = proc.communicate()
             if proc.returncode:
                 logger.error('Failed to delete cgroup: {}'.format(stderr))
@@ -436,38 +439,40 @@ class Runner(object):
         '''
         A generator that will return all ansible job events in the order that they were emitted from Ansible
 
-        Example:
+        :Example:
+
+        .. code-block::
 
             {
-               "event":"runner_on_ok",
-               "uuid":"00a50d9c-161a-4b74-b978-9f60becaf209",
-               "stdout":"ok: [localhost] => {\\r\\n    \\"   msg\\":\\"Test!\\"\\r\\n}",
-               "counter":6,
-               "pid":740,
-               "created":"2018-04-05T18:24:36.096725",
-               "end_line":10,
-               "start_line":7,
-               "event_data":{
-                  "play_pattern":"all",
-                  "play":"all",
-                  "task":"debug",
-                  "task_args":"msg=Test!",
-                  "remote_addr":"localhost",
-                  "res":{
-                     "msg":"Test!",
-                     "changed":false,
-                     "_ansible_verbose_always":true,
-                     "_ansible_no_log":false
+               "event": "runner_on_ok",
+               "uuid": "00a50d9c-161a-4b74-b978-9f60becaf209",
+               "stdout": "ok: [localhost] => {\\r\\n    \\"   msg\\":\\"Test!\\"\\r\\n}",
+               "counter": 6,
+               "pid": 740,
+               "created": "2018-04-05T18:24:36.096725",
+               "end_line": 10,
+               "start_line": 7,
+               "event_data": {
+                  "play_pattern": "all",
+                  "play": "all",
+                  "task": "debug",
+                  "task_args": "msg=Test!",
+                  "remote_addr": "localhost",
+                  "res": {
+                     "msg": "Test!",
+                     "changed": false,
+                     "_ansible_verbose_always": true,
+                     "_ansible_no_log": false
                   },
-                  "pid":740,
-                  "play_uuid":"0242ac11-0002-443b-cdb1-000000000006",
-                  "task_uuid":"0242ac11-0002-443b-cdb1-000000000008",
-                  "event_loop":null,
-                  "playbook_uuid":"634edeee-3228-4c17-a1b4-f010fdd42eb2",
-                  "playbook":"test.yml",
-                  "task_action":"debug",
-                  "host":"localhost",
-                  "task_path":"/tmp/demo/project/test.yml:3"
+                  "pid": 740,
+                  "play_uuid": "0242ac11-0002-443b-cdb1-000000000006",
+                  "task_uuid": "0242ac11-0002-443b-cdb1-000000000008",
+                  "event_loop": null,
+                  "playbook_uuid": "634edeee-3228-4c17-a1b4-f010fdd42eb2",
+                  "playbook": "test.yml",
+                  "task_action": "debug",
+                  "host": "localhost",
+                  "task_path": "/tmp/demo/project/test.yml:3"
                }
            }
         '''
@@ -530,8 +535,8 @@ class Runner(object):
         container_name = self.config.container_name
         if container_name:
             container_cli = self.config.process_isolation_executable
-            cmd = '{} kill {}'.format(container_cli, container_name)
-            proc = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
+            cmd = [container_cli, 'kill', container_name]
+            proc = Popen(cmd, stdout=PIPE, stderr=PIPE)
             _, stderr = proc.communicate()
             if proc.returncode:
                 logger.info('Error from {} kill {} command:\n{}'.format(container_cli, container_name, stderr))
@@ -541,7 +546,7 @@ class Runner(object):
     @classmethod
     def handle_termination(cls, pid, pidfile=None, is_cancel=True):
         '''
-        Internal method to terminate a subprocess spawned by `pexpect` representing an invocation of runner.
+        Internal method to terminate a subprocess spawned by ``pexpect`` representing an invocation of runner.
 
         :param pid:       the process id of the running the job.
         :param pidfile:   the daemon's PID file
